@@ -1,14 +1,19 @@
 #' R + mermaid.js
 #'
-#' Make diagrams in R using \href{https://github.com/knsv/mermaid/wiki}{mermaid.js}
-#' with infrastructure provided by \href{http://www.htmlwidgets.org/}{htmlwidgets}.
+#' Make diagrams in R using \href{https://github.com/mdaines/viz.js}{viz.js} or
+#' \href{https://github.com/knsv/mermaid}{mermaid.js} with infrastructure
+#' provided by \href{http://www.htmlwidgets.org/}{htmlwidgets}.
 #' 
-#' @param diagram string diagram in mermaid markdown-like language.
-#' If no diagram is provided \code{diagram = ""} then the function will assume that
+#' @param diagram diagram in \code{graphviz} or \code{mermaid} format or a 
+#' file (as a connection or file name) containing a diagram specification. The
+#' recommended filename extensions are '.gv' and '.mmd' for the Graphviz and the
+#' mermaid diagram specifications, respectively. If no diagram is provided,
+#' \code{diagram = ""} then the function will assume that
 #' a diagram will be provided by \code{\link[htmltools]{tags}} and
 #' \code{DiagrammeR} is just being used for dependency injection.
-#' @param width the width of the resulting graphic in pixels.
-#' @param height the height of the resulting graphic in pixels.
+#' @param type string - either "mermaid" (default) or "grViz" indicating
+#' the type of diagram spec and the desired parser/renderer
+#' @param ... any other parameters to pass to \code{grViz} or \code{mermaid}
 #' @return An object of class \code{htmlwidget} that will
 #' intelligently print itself into HTML in a variety of contexts
 #' including the R console, within R Markdown documents,
@@ -17,25 +22,25 @@
 #' \dontrun{
 #' # note the whitespace is not important
 #' DiagrammeR("
-#'   graph LR;
-#'     A-->B;
-#'     A-->C;
-#'     C-->E;
-#'     B-->D;
-#'     C-->D;
-#'     D-->F;
-#'     E-->F;
+#'   graph LR
+#'     A-->B
+#'     A-->C
+#'     C-->E
+#'     B-->D
+#'     C-->D
+#'     D-->F
+#'     E-->F
 #' ")
 #' 
 #' DiagrammeR("
-#'    graph TB;
-#'    A-->B;
-#'    A-->C;
-#'    C-->E;
-#'    B-->D;
-#'    C-->D;
-#'    D-->F;
-#'    E-->F;
+#'    graph TB
+#'    A-->B
+#'    A-->C
+#'    C-->E
+#'    B-->D
+#'    C-->D
+#'    D-->F
+#'    E-->F
 #' ")
 #' 
 #' DiagrammeR("graph LR;A(Rounded)-->B[Squared];B-->C{A Decision};
@@ -88,35 +93,44 @@
 #'   ,tags$div(class="mermaid",diagramSpec)
 #'   ,DiagrammeR()
 #' ))
+#' 
+#' # sequence diagrams
+#' # Using this "How to Draw a Sequence Diagram" 
+#' #   http://www.cs.uku.fi/research/publications/reports/A-2003-1/page91.pdf
+#' # draw some sequence diagrams with DiagrammeR
+#' 
+#' library(DiagrammeR)
+#' 
+#' DiagrammeR("
+#' sequenceDiagram;
+#'    customer->>ticket seller: ask ticket;
+#'    ticket seller->>database: seats;
+#'    alt tickets available
+#'      database->>ticket seller: ok;
+#'      ticket seller->>customer: confirm;
+#'      customer->>ticket seller: ok;
+#'      ticket seller->>database: book a seat;
+#'      ticket seller->>printer: print ticket;
+#'    else sold out
+#'      database->>ticket seller: none left;
+#'      ticket seller->>customer:  sorry;
+#'    end
+#' ")
 #' }
+#' 
 #' @import htmlwidgets
 #'
 #' @export
 
-DiagrammeR <- function(diagram = "", width = NULL, height = NULL) {
-  
-  # check for vector with length > 1 and concatenate
-  if (length(diagram) > 1 ){
-    
-    nosep <- grep(x = diagram, pattern = "[;\n]")
-    
-    if (length(nosep) < length(diagram)){
-      diagram[-nosep] <- sapply(diagram[-nosep],
-                                function(c){paste0(c, ";")})
-    }
-    
-    diagram = paste0( diagram, collapse = "" )
+DiagrammeR <- function(diagram = "", type = "mermaid", ...) {
+  # DiagrammeR will serve as a wrapper function for mermaid and grVis
+  if ( grepl(x = type, pattern = "[m,M](erm).*") ) {
+    mermaid( diagram, ... )
+  } else if( grepl( x = type, pattern = "[g,G]?[r,R]?.*[v,V][i].*" )  ) {
+    grViz( diagram, ... )
+  } else {
+    stop ( "type should equal 'mermaid' or 'grViz' ")
   }
-  
-  # forward options using x
-  x <- list(diagram = diagram)
-  
-  # create widget
-  htmlwidgets::createWidget(name = 'DiagrammeR',
-                            x,
-                            width = width,
-                            height = height,
-                            package = 'DiagrammeR')
 }
 
 #' Widget output function for use in Shiny
