@@ -20,7 +20,45 @@ HTMLWidgets.widget({
         allowing us to callback after manually init and then callback
         after complete
     */
-   window.mermaid.startOnLoad = false;
+    window.mermaid.startOnLoad = false;
+    
+    // set config options for Gantt
+    //   undocumented but these can be provided
+    //   so from R
+    //   m1 <- mermaid(spec)
+    //   m1$x$config = list(ganttConfig = list( barHeight = 100 ) )
+    mermaid.ganttConfig = {
+        titleTopMargin:25,
+        barHeight:20,
+        barGap:4,
+        topPadding:50,
+        sidePadding:100,
+        gridLineStartPadding:35,
+        fontSize:11,
+        numberSectionStyles:4,
+        axisFormatter: [
+            // Within a day
+            ["%I:%M", function (d) {
+                return d.getHours();
+            }],
+            // Monday a week
+            ["w. %U", function (d) {
+                return d.getDay() == 1;
+            }],
+            // Day within a week (not monday)
+            ["%a %d", function (d) {
+                return d.getDay() && d.getDate() != 1;
+            }],
+            // within a month
+            ["%b %d", function (d) {
+                return d.getDate() != 1;
+            }],
+            // Month
+            ["%m-%y", function (d) {
+                return d.getMonth();
+            }]
+        ]
+    };
 
     return {
       // TODO: add instance fields as required
@@ -49,6 +87,19 @@ HTMLWidgets.widget({
       el.style.display = "none";
     }
     
+    // check for undocumented ganttConfig
+    //   to override the defaults manually entered
+    //   in initialize above
+    //   note this is really sloppy and will not
+    //   work well if multiple gantt charts
+    //   with custom configs here
+    if( typeof x.config !== "undefined" && 
+         typeof x.config.ganttConfig !== "undefined" ){
+      Object.keys(x.config.ganttConfig).map(function(k){
+        window.mermaid.ganttConfig[k] = x.config.ganttConfig[k];
+      })
+    }
+    
     
     // use this to sort of make our diagram responsive
     //  or at a minimum fit within the bounds set by htmlwidgets
@@ -63,29 +114,7 @@ HTMLWidgets.widget({
        }
     };
 
-    // set up a container for tasks to perform after completion
-    //  one example would be add callbacks for event handling
-    //  styling
-    if (typeof mermaid.tasks === "undefined"){
-      mermaid.tasks = [];
-    }
-      
-    if (!(typeof x.tasks === "undefined") ){
-      if ( (typeof x.tasks.length === "undefined") ||
-       (typeof x.tasks === "function" ) ) {
-         // handle a function not enclosed in array
-         // should be able to remove once using jsonlite
-         x.tasks = [x.tasks];
-      }
-      x.tasks.map(function(t){
-        // for each tasks add it to the mermaid.tasks with el
-        mermaid.tasks.push(
-          {"task": t, "el": el}
-        );
-      })
-    }
 
-  
     // get all DiagrammeR mermaids widgets
     dg = document.getElementsByClassName("DiagrammeR");
     // run mermaid.init
@@ -106,35 +135,29 @@ HTMLWidgets.widget({
         .attr("id", "mermaidChart-" + el.id);
       // now we have to change the styling assigned by mermaid
       //   to point to our new id that we have assigned
-      d3.select(el).select("svg").select("style")[0][0].innerHTML = d3.select(el).select("svg")
-        .select("style")[0][0].innerHTML
-        .replace(/mermaidChart[0-9]*/gi, "mermaidChart-" + el.id);
-
-      /*
-      //difficult way to change the stylesheet
-      //     thought it would be more robust but the above
-      //     works better
-      for( i = 0; i <  document.styleSheets.length; i++ ) {
-        var s = document.styleSheets[i];
-        // find the stylesheet for this widget
-        if(s.ownerNode.parentNode.parentNode.id === el.id){
-          // use http://davidwalsh.name/add-rules-stylesheets
-          //  to change the rules to use our new svg id in css
-          var howManyRules = s.cssRules.length;
-          for ( rule = 0; rule < howManyRules; rule++){
-            s.insertRule(
-      */
-      //        s.cssRules.item(rule).cssText.replace(/mermaidChart[0-9]*/gi, "mermaidChart-" + el.id),
-      /*        howManyRules
-            );
-          }
-          // now delete the original rules          
-          for ( rule = 0; rule < howManyRules ; rule++){
-            s.deleteRule(rule);
-          }
-        }
+      //   will add if since sequence diagrams do not have stylesheet
+      if(d3.select(el).select("svg").select("style")[0][0]){
+        d3.select(el).select("svg").select("style")[0][0].innerHTML = d3.select(el).select("svg")
+          .select("style")[0][0].innerHTML
+          .replace(/mermaidChart[0-9]*/gi, "mermaidChart-" + el.id);
       }
-      */
+        
+      // set up a container for tasks to perform after completion
+      //  one example would be add callbacks for event handling
+      //  styling
+      if (!(typeof x.tasks === "undefined") ){
+        if ( (typeof x.tasks.length === "undefined") ||
+         (typeof x.tasks === "function" ) ) {
+           // handle a function not enclosed in array
+           // should be able to remove once using jsonlite
+           x.tasks = [x.tasks];
+        }
+        x.tasks.map(function(t){
+          // for each tasks add it to the mermaid.tasks with el
+          t.call(el);
+        })
+      }
+
     } catch(e) {
       // if error look for last processed DiagrammeR
       //  and send error to the container div
@@ -153,28 +176,7 @@ HTMLWidgets.widget({
       
       processedDg.append("pre").html( ["parse error with " + x.diagram, e.message].join("\n") )
     }
-    
-    // makeResponsive needs to be run again with shiny
-    //  since asynchrony sometimes results in not run
-    if( HTMLWidgets.shinyMode ){
-      for ( i = 0 ; i < dg.length; i++ ){
-        makeResponsive( dg[i] )
-      }
-    }
 
-    // will this ensure synchronous order of execution
-    //  the first set of tests seem to indicate they will
-    //  but it should be more robustly tested
-    if(!(typeof mermaid.tasks.length === "undefined" ) ) {
-      mermaid.tasks.forEach(function(t) { 
-        //add some error checking here
-        if ( typeof t.task === "function" ){
-          t.task.call(null, t.el);
-        } else {
-          console.log("task not a function so skipped");
-        }
-      });
-    }
   },
 
   resize: function(el, width, height, instance) {
